function p=bloodp(x,y,z)

% x= high blood pressure index (0= normal, 1= mildly elevated bp, etc.)
% y= cholesterol level (0= low, ..., 4= highly elevated)
% z= weight in pounds

alpha= 2.01 - (y+1)/5 - z/300;
p= exp(-alpha*x)*(1-exp(-alpha))/(1-exp(-5*alpha));
